from . import views

urls = []
